==> angular-materializecss-wrapper-16.0.1.tgz: package/lib_esmodule/materialize-directive.js <==
import { Directive, ElementRef, EventEmitter, inject, Input, Output } from '@angular/core';
import { CustomEvent } from './custom-event-polyfill';
import * as i0 from "@angular/core";
var MaterializeDirective = (function () {
    function MaterializeDirective() {
        this._params = null;
        this._functionName = null;
        this.previousValue = null;
        this.previousDisabled = false;
        this._waitFunction = {};
        this._el = inject(ElementRef);
        this.changeListenerShouldBeAdded = true;
        this.init = new EventEmitter();
        this.initialized = false;
    }
    Object.defineProperty(MaterializeDirective.prototype, "materializeParams", {
        set: function (params) {
            this._params = params;
            this.performElementUpdates();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaterializeDirective.prototype, "materializeActions", {
        set: function (actions) {
            var _this = this;
            actions.subscribe(function (action) {
                window.setTimeout(function () {
                    if (typeof action === "string") {
                        _this.performLocalElementUpdates(action);
                    }
                    else {
                        _this.performLocalElementUpdates(action.action, action.params);
                    }
                }, 1);
            });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaterializeDirective.prototype, "materialize", {
        set: function (functionName) {
            this._functionName = functionName;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaterializeDirective.prototype, "materializeSelectOptions", {
        set: function (_options) {
        },
        enumerable: false,
        configurable: true
    });
    MaterializeDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            _this.performElementUpdates();
        });
    };
    MaterializeDirective.prototype.ngOnChanges = function (_unused) {
        var _this = this;
        if (this.isSelect()) {
            setTimeout(function () { return _this.performLocalElementUpdates(); }, 10);
        }
    };
    MaterializeDirective.prototype.ngOnDestroy = function () {
        this.performElementRemotion();
    };
    MaterializeDirective.prototype.ngDoCheck = function () {
        var nativeElement = this._el.nativeElement;
        var jQueryElement = $(nativeElement);
        if (this.isSelect()) {
            var shouldUpdate = false;
            if (nativeElement.disabled != this.previousDisabled) {
                this.previousDisabled = nativeElement.disabled;
                shouldUpdate = true;
            }
            if (!jQueryElement.attr("multiple") && nativeElement.value != this.previousValue) {
                this.previousValue = nativeElement.value;
                shouldUpdate = true;
            }
            if (shouldUpdate) {
                this.performLocalElementUpdates();
            }
        }
        else if (this.isTextarea()) {
            if (nativeElement.value != this.previousValue) {
                this.previousValue = nativeElement.value;
                this.performElementUpdates();
            }
        }
        return false;
    };
    MaterializeDirective.prototype.performElementRemotion = function () {
        if (this.isTooltip()) {
            var nativeElement = this._el.nativeElement;
            var jQueryElement = $(nativeElement);
            var tooltipId = jQueryElement.attr('data-tooltip-id');
            if (tooltipId) {
                $('#' + tooltipId).remove();
            }
        }
    };
    MaterializeDirective.prototype.performElementUpdates = function () {
        var _this = this;
        if (M && M.updateTextFields) {
            M.updateTextFields();
        }
        if (this.isSelect() && this.changeListenerShouldBeAdded) {
            var nativeElement_1 = this._el.nativeElement;
            var jQueryElement = $(nativeElement_1);
            jQueryElement.on("change", function (e) {
                if (!e.originalEvent || !e.originalEvent.internalToMaterialize) {
                    var event_1 = document.createEvent("CustomEvent");
                    event_1.initCustomEvent("change", false, false, undefined);
                    event_1.internalToMaterialize = true;
                    nativeElement_1.dispatchEvent(event_1);
                }
            });
            this.changeListenerShouldBeAdded = false;
        }
        if (this.isAutocomplete()) {
            var nativeElement_2 = this._el.nativeElement;
            var jQueryElement = $(nativeElement_2);
            jQueryElement.on("change", function (_e) { return nativeElement_2.dispatchEvent(CustomEvent("input")); });
        }
        if (this.isDatePicker()) {
            var nativeElement_3 = this._el.nativeElement;
            var jqueryPickerElement_1 = $(nativeElement_3);
            var datePicker = jqueryPickerElement_1[this._functionName].apply(jqueryPickerElement_1, this._params);
            var picker_1 = datePicker.pickadate('picker');
            setTimeout(function () {
                if (_this.ngModel) {
                    picker_1.set('select', _this.ngModel);
                }
                else {
                    var value = jqueryPickerElement_1.val();
                    if (value && value.length > 0) {
                        picker_1.set('select', value);
                    }
                }
                jqueryPickerElement_1.on('change', function (_e) { return nativeElement_3.dispatchEvent(CustomEvent("input")); });
            });
        }
        if (this.isTimePicker()) {
            var nativeElement_4 = this._el.nativeElement;
            var jqueryPickerElement_2 = $(nativeElement_4);
            var timePicker = jqueryPickerElement_2[this._functionName].apply(jqueryPickerElement_2, this._params);
            var picker_2 = timePicker.pickatime('picker');
            setTimeout(function () {
                if (_this.ngModel) {
                    picker_2.val(_this.ngModel);
                }
                else {
                    picker_2.val(jqueryPickerElement_2.val());
                }
                jqueryPickerElement_2.on('change', function (_e) { return nativeElement_4.dispatchEvent(CustomEvent("input")); });
            });
        }
        if (this.isChips()) {
            var nativeElement_5 = this._el.nativeElement;
            var jQueryElement = $(nativeElement_5);
            jQueryElement.on("chip.add", function (_e, chip) { return nativeElement_5.dispatchEvent(CustomEvent("chip.add", chip)); });
            jQueryElement.on("chip.delete", function (_e, chip) { return nativeElement_5.dispatchEvent(CustomEvent("chip.delete", chip)); });
            jQueryElement.on("chip.select", function (_e, chip) { return nativeElement_5.dispatchEvent(CustomEvent("chip.select", chip)); });
        }
        if (this.isTextarea()) {
            this._el.nativeElement.dispatchEvent(CustomEvent("autoresize", {
                bubbles: true,
                cancelable: false,
                detail: undefined
            }));
        }
        this.performLocalElementUpdates();
    };
    MaterializeDirective.prototype.performLocalElementUpdates = function (functionName, params) {
        var _this = this;
        if (functionName === void 0) { functionName = this._functionName; }
        if (params === void 0) { params = this._params; }
        if (this._waitFunction[functionName]) {
            return;
        }
        this._waitFunction[functionName] = true;
        $(document).ready(function () {
            _this._waitFunction[functionName] = false;
            if (functionName) {
                var jQueryElement = $(_this._el.nativeElement);
                if (jQueryElement[functionName]) {
                    if (params) {
                        if (params instanceof Array) {
                            jQueryElement[functionName].apply(jQueryElement, params);
                        }
                        else {
                            throw new Error("Params has to be an array.");
                        }
                    }
                    else {
                        jQueryElement[functionName]();
                    }
                }
                else {
                    if (M[functionName]) {
                        if (params) {
                            if (params instanceof Array) {
                                M[functionName].apply(M, params);
                            }
                            else {
                                throw new Error("Params has to be an array.");
                            }
                        }
                        else {
                            M[functionName]();
                        }
                    }
                    else {
                        throw new Error("Couldn't find materialize function ''" + functionName + "' on element or the global Materialize object.");
                    }
                }
                if (!_this.initialized) {
                    _this.initialized = true;
                    _this.init.emit();
                }
            }
        });
    };
    MaterializeDirective.prototype.isTooltip = function () {
        return (this._functionName && this._functionName === "tooltip");
    };
    MaterializeDirective.prototype.isSelect = function () {
        return (this._functionName && this._functionName === "material_select");
    };
    MaterializeDirective.prototype.isDatePicker = function () {
        return (this._functionName && this._functionName === "pickadate");
    };
    MaterializeDirective.prototype.isTimePicker = function () {
        return (this._functionName && this._functionName === "pickatime");
    };
    MaterializeDirective.prototype.isChips = function () {
        return (this._functionName && this._functionName === "material_chip");
    };
    MaterializeDirective.prototype.isAutocomplete = function () {
        return (this._functionName && this._functionName === "autocomplete");
    };
    MaterializeDirective.prototype.isTextarea = function () {
        return this._el.nativeElement.nodeName == "TEXTAREA";
    };
    MaterializeDirective.ɵfac = function MaterializeDirective_Factory(t) { return new (t || MaterializeDirective)(); };
    MaterializeDirective.ɵdir = i0.ɵɵdefineDirective({ type: MaterializeDirective, selectors: [["", "materialize", ""]], inputs: { materializeParams: "materializeParams", materializeActions: "materializeActions", materialize: "materialize", materializeSelectOptions: "materializeSelectOptions", ngModel: "ngModel" }, outputs: { init: "init" }, features: [i0.ɵɵNgOnChangesFeature] });
    return MaterializeDirective;
}());
export { MaterializeDirective };
(function () { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(MaterializeDirective, [{
        type: Directive,
        args: [{
                selector: '[materialize]'
            }]
    }], function () { return []; }, { init: [{
            type: Output
        }], materializeParams: [{
            type: Input
        }], materializeActions: [{
            type: Input
        }], materialize: [{
            type: Input
        }], materializeSelectOptions: [{
            type: Input
        }], ngModel: [{
            type: Input
        }] }); })();

==> angular-materializecss-wrapper-16.0.2.tgz: package/lib_esmodule/materialize-directive.js <==
import { Directive, ElementRef, EventEmitter, inject, Input, Output } from '@angular/core';
import { CustomEvent } from './custom-event-polyfill';
import * as i0 from "@angular/core";
var MaterializeDirective = (function () {
    function MaterializeDirective() {
        this._params = null;
        this._functionName = null;
        this.previousValue = null;
        this.previousDisabled = false;
        this._waitFunction = {};
        this._el = inject(ElementRef);
        this.changeListenerShouldBeAdded = true;
        this.init = new EventEmitter();
        this.initialized = false;
    }
    Object.defineProperty(MaterializeDirective.prototype, "materializeParams", {
        set: function (params) {
            this._params = params;
            this.performElementUpdates();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaterializeDirective.prototype, "materializeActions", {
        set: function (actions) {
            var _this = this;
            actions.subscribe(function (action) {
                window.setTimeout(function () {
                    if (typeof action === "string") {
                        _this.performLocalElementUpdates(action);
                    }
                    else {
                        _this.performLocalElementUpdates(action.action, action.params);
                    }
                }, 1);
            });
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaterializeDirective.prototype, "materialize", {
        set: function (functionName) {
            this._functionName = functionName;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaterializeDirective.prototype, "materializeSelectOptions", {
        set: function (_options) {
        },
        enumerable: false,
        configurable: true
    });
    MaterializeDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            _this.performElementUpdates();
        });
    };
    MaterializeDirective.prototype.ngOnChanges = function (_unused) {
        var _this = this;
        if (this.isSelect()) {
            setTimeout(function () { return _this.performLocalElementUpdates(); }, 10);
        }
    };
    MaterializeDirective.prototype.ngOnDestroy = function () {
        this.performElementRemotion();
    };
    MaterializeDirective.prototype.ngDoCheck = function () {
        var nativeElement = this._el.nativeElement;
        var jQueryElement = $(nativeElement);
        if (this.isSelect()) {
            var shouldUpdate = false;
            if (nativeElement.disabled != this.previousDisabled) {
                this.previousDisabled = nativeElement.disabled;
                shouldUpdate = true;
            }
            if (!jQueryElement.attr("multiple") && nativeElement.value != this.previousValue) {
                this.previousValue = nativeElement.value;
                shouldUpdate = true;
            }
            if (shouldUpdate) {
                this.performLocalElementUpdates();
            }
        }
        else if (this.isTextarea()) {
            if (nativeElement.value != this.previousValue) {
                this.previousValue = nativeElement.value;
                this.performElementUpdates();
            }
        }
        return false;
    };
    MaterializeDirective.prototype.performElementRemotion = function () {
        if (this.isTooltip()) {
            var nativeElement = this._el.nativeElement;
            var jQueryElement = $(nativeElement);
            var tooltipId = jQueryElement.attr('data-tooltip-id');
            if (tooltipId) {
                $('#' + tooltipId).remove();
            }
        }
    };
    MaterializeDirective.prototype.performElementUpdates = function () {
        var _this = this;
        if (Materialize && Materialize.updateTextFields) {
            Materialize.updateTextFields();
        }
        if (this.isSelect() && this.changeListenerShouldBeAdded) {
            var nativeElement_1 = this._el.nativeElement;
            var jQueryElement = $(nativeElement_1);
            jQueryElement.on("change", function (e) {
                if (!e.originalEvent || !e.originalEvent.internalToMaterialize) {
                    var event_1 = document.createEvent("CustomEvent");
                    event_1.initCustomEvent("change", false, false, undefined);
                    event_1.internalToMaterialize = true;
                    nativeElement_1.dispatchEvent(event_1);
                }
            });
            this.changeListenerShouldBeAdded = false;
        }
        if (this.isAutocomplete()) {
            var nativeElement_2 = this._el.nativeElement;
            var jQueryElement = $(nativeElement_2);
            jQueryElement.on("change", function (_e) { return nativeElement_2.dispatchEvent(CustomEvent("input")); });
        }
        if (this.isDatePicker()) {
            var nativeElement_3 = this._el.nativeElement;
            var jqueryPickerElement_1 = $(nativeElement_3);
            var datePicker = jqueryPickerElement_1[this._functionName].apply(jqueryPickerElement_1, this._params);
            var picker_1 = datePicker.pickadate('picker');
            setTimeout(function () {
                if (_this.ngModel) {
                    picker_1.set('select', _this.ngModel);
                }
                else {
                    var value = jqueryPickerElement_1.val();
                    if (value && value.length > 0) {
                        picker_1.set('select', value);
                    }
                }
                jqueryPickerElement_1.on('change', function (_e) { return nativeElement_3.dispatchEvent(CustomEvent("input")); });
            });
        }
        if (this.isTimePicker()) {
            var nativeElement_4 = this._el.nativeElement;
            var jqueryPickerElement_2 = $(nativeElement_4);
            var timePicker = jqueryPickerElement_2[this._functionName].apply(jqueryPickerElement_2, this._params);
            var picker_2 = timePicker.pickatime('picker');
            setTimeout(function () {
                if (_this.ngModel) {
                    picker_2.val(_this.ngModel);
                }
                else {
                    picker_2.val(jqueryPickerElement_2.val());
                }
                jqueryPickerElement_2.on('change', function (_e) { return nativeElement_4.dispatchEvent(CustomEvent("input")); });
            });
        }
        if (this.isChips()) {
            var nativeElement_5 = this._el.nativeElement;
            var jQueryElement = $(nativeElement_5);
            jQueryElement.on("chip.add", function (_e, chip) { return nativeElement_5.dispatchEvent(CustomEvent("chip.add", chip)); });
            jQueryElement.on("chip.delete", function (_e, chip) { return nativeElement_5.dispatchEvent(CustomEvent("chip.delete", chip)); });
            jQueryElement.on("chip.select", function (_e, chip) { return nativeElement_5.dispatchEvent(CustomEvent("chip.select", chip)); });
        }
        if (this.isTextarea()) {
            this._el.nativeElement.dispatchEvent(CustomEvent("autoresize", {
                bubbles: true,
                cancelable: false,
                detail: undefined
            }));
        }
        this.performLocalElementUpdates();
    };
    MaterializeDirective.prototype.performLocalElementUpdates = function (functionName, params) {
        var _this = this;
        if (functionName === void 0) { functionName = this._functionName; }
        if (params === void 0) { params = this._params; }
        if (this._waitFunction[functionName]) {
            return;
        }
        this._waitFunction[functionName] = true;
        $(document).ready(function () {
            _this._waitFunction[functionName] = false;
            if (functionName) {
                var jQueryElement = $(_this._el.nativeElement);
                if (jQueryElement[functionName]) {
                    if (params) {
                        if (params instanceof Array) {
                            jQueryElement[functionName].apply(jQueryElement, params);
                        }
                        else {
                            throw new Error("Params has to be an array.");
                        }
                    }
                    else {
                        jQueryElement[functionName]();
                    }
                }
                else {
                    if (Materialize[functionName]) {
                        if (params) {
                            if (params instanceof Array) {
                                Materialize[functionName].apply(Materialize, params);
                            }
                            else {
                                throw new Error("Params has to be an array.");
                            }
                        }
                        else {
                            Materialize[functionName]();
                        }
                    }
                    else {
                        throw new Error("Couldn't find materialize function ''" + functionName + "' on element or the global Materialize object.");
                    }
                }
                if (!_this.initialized) {
                    _this.initialized = true;
                    _this.init.emit();
                }
            }
        });
    };
    MaterializeDirective.prototype.isTooltip = function () {
        return (this._functionName && this._functionName === "tooltip");
    };
    MaterializeDirective.prototype.isSelect = function () {
        return (this._functionName && this._functionName === "material_select");
    };
    MaterializeDirective.prototype.isDatePicker = function () {
        return (this._functionName && this._functionName === "pickadate");
    };
    MaterializeDirective.prototype.isTimePicker = function () {
        return (this._functionName && this._functionName === "pickatime");
    };
    MaterializeDirective.prototype.isChips = function () {
        return (this._functionName && this._functionName === "material_chip");
    };
    MaterializeDirective.prototype.isAutocomplete = function () {
        return (this._functionName && this._functionName === "autocomplete");
    };
    MaterializeDirective.prototype.isTextarea = function () {
        return this._el.nativeElement.nodeName == "TEXTAREA";
    };
    MaterializeDirective.ɵfac = function MaterializeDirective_Factory(t) { return new (t || MaterializeDirective)(); };
    MaterializeDirective.ɵdir = i0.ɵɵdefineDirective({ type: MaterializeDirective, selectors: [["", "materialize", ""]], inputs: { materializeParams: "materializeParams", materializeActions: "materializeActions", materialize: "materialize", materializeSelectOptions: "materializeSelectOptions", ngModel: "ngModel" }, outputs: { init: "init" }, features: [i0.ɵɵNgOnChangesFeature] });
    return MaterializeDirective;
}());
export { MaterializeDirective };
(function () { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(MaterializeDirective, [{
        type: Directive,
        args: [{
                selector: '[materialize]'
            }]
    }], function () { return []; }, { init: [{
            type: Output
        }], materializeParams: [{
            type: Input
        }], materializeActions: [{
            type: Input
        }], materialize: [{
            type: Input
        }], materializeSelectOptions: [{
            type: Input
        }], ngModel: [{
            type: Input
        }] }); })();
